import unittest
import os
import shutil
import tempfile as tmp

from packutil import *

TEST_FILES_PATH = 'test_files'


class Unpacking(unittest.TestCase):

    def setUp(self):
        self.temp_path = tmp.mkdtemp()


    def tearDown(self):
        shutil.rmtree(self.temp_path)
        pass


    def unpack_test(self, unpack_f, extension):
        original_name = 'file'
        original_fpath = os.path.join(TEST_FILES_PATH, original_name)
        compressed_fname = '%s.%s' % (original_name, extension)
        compressed_fpath = os.path.join(TEST_FILES_PATH, compressed_fname)
        unpack_f(compressed_fpath, self.temp_path)
        unpacked_fpath = os.path.join(self.temp_path, original_name)

        self.assertTrue(os.path.isfile(unpacked_fpath))
        with open(unpacked_fpath) as funpacked, open(original_fpath) as original:
            self.assertEqual(funpacked.read(), original.read())


    def test_unzip(self):
        extension = 'zip'
        self.unpack_test(unzip, extension)
        self.unpack_test(unpack, extension)


    def test_untar(self):
        extension = 'tar'
        self.unpack_test(untar, extension)
        self.unpack_test(unpack, extension)


    def test_ungzip(self):
        extension = 'gz'
        self.unpack_test(ungzip, extension)
        self.unpack_test(unpack, extension)


    def test_untargz(self):
        self.unpack_test(unpack, 'tar.gz')
