import os, re
from subprocess import check_output


def parse_name(fname):
    '''Parse submission attributes from filename.

    The filename format is:
        paper<submission id>-<year>-<issue>-source
    '''
    return fname[5:].split('-')[:3]


def job_key(submission, year, issue):
    return '-'.join([submission, year, issue])


def read_dois(file_path):
    '''Return list of DOIs.'''
    with open(file_path) as f:
        return f.readline()


def get_pdf_text(pdf_path):
    cmd = 'pdftotext %s -enc UTF-8 -f 1 -l 1 -raw' % pdf_path
    return check_output(cmd.split())


def rmfile(fpath):
    if os.path.exists(fpath):
        os.remove(fpath)


def make_dir(dpath):
    if not os.path.exists(dpath):
        os.makedirs(dpath)

def bytes_to_str(data):
    return "".join( chr(x) for x in bytearray(data) )

def parse_author_name(fn, ln):
    fns, lns = fn.split(" "), ln.split(" ")
    if len(fns) == 1 and len(lns) == 1:
        # Abc Def
        return f"{fn} {ln}"
    elif len(lns) > 1:
        # Abc / von Def
        return f"{fn} / {ln}"
    elif len(fns) > 1:
        abbrs = re.findall(r"\w\.", fn)
        if len(fns) - len(abbrs) == 1 and fns[1:] == abbrs:
            # Abc X. Def
            # Abc X. Y. Z. Def
            return f"{fn} {ln}"
    # Abc Xyz / Def
    # L. Abc / Def
    # Abc Xyz G. / Def
    return f"{fn} / {ln}"